@@ -1,4 +1,4 @@
-our $VERSION = '0.941';
+package Linux::realtimed;
 
 =encoding utf8
 
@@ -72,3 +72,5 @@ This daemon is free software and is distributed under same terms as Perl itself.
 Copyright 2010-2038 by Anselmo Canfora.
 
 =cut
+
+1;
